@@ -1,4 +1,4 @@
-// Copyright (C) 2003-2020 Free Software Foundation, Inc.
+// Copyright (C) 2003-2023 Free Software Foundation, Inc.
 //
 // This file is part of the GNU ISO C++ Library.  This library is free
 // software; you can redistribute it and/or modify it under the
@@ -22,26 +22,25 @@
 #include <locale>
 #include <sstream>
 #include <ctime>
-#include <cstring>
 #include <testsuite_hooks.h>
 
 class TP : public std::time_put<wchar_t>
 {
 public:
-  mutable std::wstring fill_chars;
+  mutable std::string format_chars;
 
 protected:
-  iter_type do_put(iter_type s, std::ios_base&, char_type fill,
-		   const std::tm*, char, char) const
+  iter_type do_put(iter_type s, std::ios_base&, char_type,
+		   const std::tm*, char format, char) const
   {
-    fill_chars.push_back(fill);
+    format_chars.push_back(format);
     return s;
   }
 };
 
 // libstdc++/12439
-// time_put::put doesn't pass fill character to do_put
-void test01()
+// time_put::put reads past end of format string
+void test03()
 {
   using namespace std;
   
@@ -51,14 +50,13 @@ void test01()
   const wchar_t* fmt = L"%c";
   
   TP tp;
-  tp.put(TP::iter_type(stream), stream, L'W', localtime(&tt),
-	 fmt, fmt + wcslen(fmt));
-  VERIFY( !tp.fill_chars.empty() );
-  VERIFY( tp.fill_chars[tp.fill_chars.length() - 1] == L'W' );
+  tp.put(TP::iter_type(stream), stream, stream.fill(), localtime(&tt),
+	 fmt, fmt + 1);
+  VERIFY( tp.format_chars.empty() );
 }
 
 int main()
 {
-  test01();
+  test03();
   return 0;
 }
